require 'uu/os/rest/dto'
require 'uu/os/uesuri'
require 'uu/os/env/process/process_message'

module UU
  module OS
    module Env
      module Process

        # Object representing final or partial result of process.
        class ProcessResult < UU::OS::REST::DTO

          # URI of process.
          # @param [String, UU::OS::UESURI]
          # @return [UU::OS::UESURI]
          attr_accessor :process_uri

          # State of process.
          # @param [String]
          # @return [String]
          attr_accessor :state

          # URI of result object.
          # @param [String, UU::OS::UESURI]
          # @return [UU::OS::UESURI]
          attr_accessor :result

          # Message of result.
          # @param [String, UU::OS::Env::Process::ProcessMessage]
          # @return [UU::OS::Env::Process::ProcessMessage]
          attr_accessor :message

          # Optional error code.
          # @param [String]
          # @return [String]
          attr_accessor :error_code

          def process_uri
            attributes[:processUri]
          end

          def process_uri=(val)
            if val
              attributes[:processUri] = UU::OS::UESURI.new(val)
            else
              attributes[:processUri] = nil
            end
          end

          def state
            attributes[:state]
          end

          def state=(val)
            attributes[:state] = val
          end

          def result
            attributes[:result]
          end

          def result=(val)
            if val
              attributes[:result] = UU::OS::UESURI.new(val)
            else
              attributes[:result] = nil
            end
          end

          def message
            attributes[:message]
          end

          def message=(val)
            if val
              attributes[:message] = UU::OS::Env::Process::ProcessMessage.new(val)
            else
              attributes[:message] = nil
            end
          end

          def error_code
            attributes[:errorCode]
          end

          def error_code=(val)
            attributes[:errorCode] = val
          end

        end

      end
    end
  end
end
